Installation instructions
=========================

BioSimulators-MASSpy is available as a command-line program and as a command-line program encapsulated into a Docker image.

Command-line program
--------------------

After installing `Python <https://www.python.org/downloads/>`_ (>= 3.7), `pip <https://pip.pypa.io/>`_, `libncurses <https://invisible-island.net/ncurses/announce.html>`_ and `libXML <http://www.xmlsoft.org/>`_, run the following command to install BioSimulators-MASSpy:

.. code-block:: text

    pip install biosimulators-masspy


Docker image with a command-line entrypoint
-------------------------------------------

After installing `Docker <https://docs.docker.com/get-docker/>`_, run the following command to install the Docker image for BioSimulators-MASSpy:

.. code-block:: text

    docker pull ghcr.io/biosimulators/masspy
